%if 0%{?fedora} || 0%{?rhel} >= 8
%global with_python3 1
%endif

%global srcname BTrees

Name:           python-%{srcname}
Version:        4.4.1
Release:        1%{?dist}
Summary:        Scalable persistent object containers

License:        ZPLv2.1
URL:            http://www.zodb.org/
Source0:        https://files.pythonhosted.org/packages/source/B/%{srcname}/%{srcname}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  python2-devel
BuildRequires:  python2-nose
BuildRequires:  python2-persistent-devel
BuildRequires:  python2-repoze-sphinx-autointerface
BuildRequires:  python2-setuptools
BuildRequires:  python2-sphinx
BuildRequires:  python-transaction
BuildRequires:  python-zope-interface

%if 0%{?with_python3}
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-persistent-devel
BuildRequires:  python3-repoze-sphinx-autointerface
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  python3-transaction
BuildRequires:  python3-zope-interface
%endif

%global common_desc                                                      \
This package contains a set of persistent object containers built around \
a modified BTree data structure.  The trees are optimized for use inside \
ZODB's "optimistic concurrency" paradigm, and include explicit           \
resolution of conflicts detected by that mechanism.

%description
%{common_desc}

%package -n python2-%{srcname}
Summary:        Scalable persistent object containers
Requires:       python2-persistent%{?_isa}
Requires:       python-zope-interface%{?_isa}

Provides:       bundled(jquery)
%{?python_provide:%python_provide python2-%{srcname}}

%description -n python2-%{srcname}
%{common_desc}

%if 0%{?with_python3}
%package -n python3-%{srcname}
Summary:        Scalable persistent object containers
Requires:       python3-persistent%{?_isa}
Requires:       python3-zope-interface%{?_isa}

Provides:       bundled(jquery)
%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
%{common_desc}
%endif

%prep
%setup -q -c

# Remove prebuilt egg and documentation
rm -fr %{srcname}-%{version}/%{srcname}.egg-info \
  %{srcname}-%{version}/docs/_build

%if 0%{?fedora}
# Update the sphinx theme name
sed -i "s/'default'/'alabaster'/" %{srcname}-%{version}/docs/conf.py
%endif

%if 0%{?with_python3}
# Prepare for a python3 build
cp -a %{srcname}-%{version} python3-%{srcname}-%{version}
%endif

%build
%global __global_cflags %__global_cflags -IBTrees

# Python 2 build
pushd %{srcname}-%{version}
%py2_build
PYTHONPATH=$(echo $PWD/build/lib.linux-*) make -C docs html \
  SPHINXBUILD=%{_bindir}/sphinx-build-%{python2_version}
popd

%if 0%{?with_python3}
# Python 3 build
pushd python3-%{srcname}-%{version}
%py3_build
PYTHONPATH=$(echo $PWD/build/lib.linux-*) make -C docs html \
  SPHINXBUILD=%{_bindir}/sphinx-build-%{python3_version}
popd
%endif

%install
# Python 2 install
pushd %{srcname}-%{version}
%py2_install
popd

%if 0%{?with_python3}
# Python 3 install
pushd python3-%{srcname}-%{version}
%py3_install
popd
%endif

# Remove unwanted documentation and source files; fix permissions (Python 2)
rm -f %{srcname}-%{version}/docs/_build/html/.buildinfo
rm -f %{buildroot}%{python2_sitearch}/%{srcname}/*{.c,.h,~}
rm -fr %{buildroot}%{python2_sitearch}/%{srcname}/tests
chmod 0755 %{buildroot}%{python2_sitearch}/%{srcname}/*.so

%if 0%{?with_python3}
# Remove unwanted documentation and source files; fix permissions (Python 3)
rm -f python3-%{srcname}-%{version}/docs/_build/html/.buildinfo
rm -f %{buildroot}%{python3_sitearch}/%{srcname}/*{.c,.h,~}
rm -fr %{buildroot}%{python3_sitearch}/%{srcname}/tests
chmod 0755 %{buildroot}%{python3_sitearch}/%{srcname}/*.so
%endif

%check
# Python 2 tests
pushd %{srcname}-%{version}
nosetests-%{python2_version}
popd

%if 0%{?with_python3}
# Python 3 tests
pushd python3-%{srcname}-%{version}
nosetests-%{python3_version}
popd
%endif

%files -n python2-%{srcname}
%doc %{srcname}-%{version}/docs/_build/html/*
%license %{srcname}-%{version}/COPYRIGHT.txt %{srcname}-%{version}/LICENSE.txt
%{python2_sitearch}/%{srcname}*

%if 0%{?with_python3}
%files -n python3-%{srcname}
%doc python3-%{srcname}-%{version}/docs/_build/html/*
%license %{srcname}-%{version}/COPYRIGHT.txt %{srcname}-%{version}/LICENSE.txt
%{python3_sitearch}/%{srcname}*
%endif

%changelog
* Wed Jan 25 2017 Jerry James <loganjerry@gmail.com> - 4.4.1-1
- New upstream version

* Sat Jan 14 2017 Jerry James <loganjerry@gmail.com> - 4.4.0-1
- New upstream version

* Fri Jan  6 2017 Jerry James <loganjerry@gmail.com> - 4.3.2-1
- New upstream version

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 4.3.1-3
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue May 17 2016 Jerry James <loganjerry@gmail.com> - 4.3.1-1
- New upstream version

* Tue May 10 2016 Jerry James <loganjerry@gmail.com> - 4.3.0-1
- New upstream version

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Feb  1 2016 Jerry James <loganjerry@gmail.com> - 4.2.0-1
- Update to current python packaging guidelines
- Actually package the documentation we built
- Run all the tests
- Don't ship the tests

* Fri Nov 13 2015 Jerry James <loganjerry@gmail.com> - 4.2.0-1
- New upstream version, fixes python 3.5 build

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.1.4-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.1.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun  8 2015 Jerry James <loganjerry@gmail.com> - 4.1.4-1
- New upstream version

* Sat May 23 2015 Jerry James <loganjerry@gmail.com> - 4.1.3-1
- New upstream version

* Tue Apr 14 2015 Jerry James <loganjerry@gmail.com> - 4.1.2-1
- New upstream version

* Mon Jan  5 2015 Jerry James <loganjerry@gmail.com> - 4.1.1-1
- New upstream version
- Drop upstreamed -overflow patch
- Use license macro

* Tue Aug 12 2014 Jerry James <loganjerry@gmail.com> - 4.0.8-2
- Add -overflow patch to fix test failures with 32-bit python 3.4

* Mon Jun  2 2014 Jerry James <loganjerry@gmail.com> - 4.0.8-1
- Initial RPM
